@@ -5,25 +5,11 @@
  * Date        : 2009-05-12
  * Description : Twain interface
  *
- * Copyright (C) 2002-2003 Stephan Stapel <stephan dot stapel at web dot de>
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009,2017 by Kare Sars <kare dot sars at iki dot fi>
+ * SPDX-FileCopyrightText: 2002-2003 Stephan Stapel <stephan dot stapel at web dot de>
+ * SPDX-FileCopyrightText: 2008-2009 Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009, 2017 Kare Sars <kare dot sars at iki dot fi>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  * ============================================================ */
 
@@ -40,6 +26,7 @@
 #define TWCPP_DOTRANSFER (0)
 
 #include <QString>
+#include <QImage>
 #include <QDebug>
 
 #include <cstring>
@@ -51,7 +38,7 @@ namespace KSaneIface
 
 KSaneWidgetPrivate::KSaneWidgetPrivate(): QWidget(0)
 {
-    // This is a dumy widget not visible. We use Qwidget to dispatch Windows event to
+    // This is a dummy widget not visible. We use Qwidget to dispatch Windows event to
     // Twain interface. This is not possible to do it using QObject as well.
 
     m_hMessageWnd     = 0;
@@ -171,7 +158,7 @@ bool KSaneWidgetPrivate::CallTwainProc(pTW_IDENTITY pOrigin, pTW_IDENTITY pDest,
 /** Called to display a dialog box to select the Twain source to use.
     This can be overridden if a list of all sources is available
     to the application. These sources can be enumerated by Twain.
-    it is not yet supportted by KSaneWidgetPrivate.
+    it is not yet supported by KSaneWidgetPrivate.
  */
 QString KSaneWidgetPrivate::SelectSource()
 {
@@ -415,7 +402,7 @@ bool KSaneWidgetPrivate::SetCapability(TW_CAPABILITY &cap)
     return false;
 }
 
-/** Sets the number of images which can be accpeted by the application at one time */
+/** Sets the number of images which can be accepted by the application at one time */
 bool KSaneWidgetPrivate::SetImageCount(TW_INT16 nCount)
 {
     saneDebug() << "SetImageCount" << nCount << (TW_UINT16)nCount;
@@ -611,7 +598,8 @@ void KSaneWidgetPrivate::ImageData(TW_MEMREF pdata, TW_IMAGEINFO &info)
 
         ds.writeRawData(bits, size);
 
-        emit ImageReady(baBmp, 0, 0, 0, (int)KSaneWidget::FormatBMP);
+        Q_EMIT ImageReady(baBmp, 0, 0, 0, (int)KSaneWidget::FormatBMP);
+        Q_EMIT qImageReady(QImage::fromData(baBmp, "BMP"));
 
         GlobalUnlock(hDIB);
 
