@@ -1,41 +1,15 @@
 /* ============================================================
  *
- * This file is part of the KDE project
+ * SPDX-FileCopyrightText: 2007-2008 Kare Sars <kare dot sars at iki dot fi>
+ * SPDX-FileCopyrightText: 2009 Grzegorz Kurtyka <grzegorz dot kurtyka at gmail dot com>
+ * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
- * Date        : 2007-09-13
- * Description : Sane interface for KDE
- *
- * Copyright (C) 2007-2008 by Kare Sars <kare dot sars at iki dot fi>
- * Copyright (C) 2009 by Grzegorz Kurtyka <grzegorz dot kurtyka at gmail dot com>
- * Copyright (C) 2014 by Gregor Mitsch: port to KDE5 frameworks
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  * ============================================================ */
 
 #include "ksanedevicedialog.h"
 
-// Sane includes
-extern "C"
-{
-#include <sane/saneopts.h>
-#include <sane/sane.h>
-}
-
 #include <QScrollArea>
 #include <QLabel>
 #include <QDialogButtonBox>
@@ -85,8 +59,7 @@ KSaneDeviceDialog::KSaneDeviceDialog(QWidget *parent)
     m_btnOk = bottomButtonBox->button(QDialogButtonBox::Ok);
     m_btnReloadDevices = bottomButtonBox->addButton(i18n("Reload devices list"), QDialogButtonBox::ButtonRole::ActionRole);
     layout->addWidget(bottomButtonBox);
-    //connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    //connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
     connect(bottomButtonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(bottomButtonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     connect(m_btnReloadDevices, &QPushButton::clicked, this, &KSaneDeviceDialog::reloadDevicesList);
@@ -95,9 +68,6 @@ KSaneDeviceDialog::KSaneDeviceDialog(QWidget *parent)
     topLayout->addWidget(bottomButtonBox);
 
     setMinimumHeight(200);
-    m_findDevThread = FindSaneDevicesThread::getInstance();
-
-    connect(m_findDevThread, &FindSaneDevicesThread::finished, this, &KSaneDeviceDialog::updateDevicesList);
 
     reloadDevicesList();
 }
@@ -115,9 +85,7 @@ void KSaneDeviceDialog::reloadDevicesList()
     m_gbDevices->layout()->itemAt(0)->widget()->hide();  // explanation
     m_btnReloadDevices->setEnabled(false);
 
-    if (!m_findDevThread->isRunning()) {
-        m_findDevThread->start();
-    }
+    Q_EMIT requestReloadList();
 }
 
 void KSaneDeviceDialog::setAvailable(bool isAvailable)
@@ -143,11 +111,10 @@ QString KSaneDeviceDialog::getSelectedName() const
     return QString();
 }
 
-void KSaneDeviceDialog::updateDevicesList()
+void KSaneDeviceDialog::updateDevicesList(const QList<KSaneCore::DeviceInfo> &list)
 {
     qDeleteAll(m_btnGroupDevices->buttons());
 
-    const QList<KSaneWidget::DeviceInfo> list = m_findDevThread->devicesList();
     if (list.isEmpty()) {
         m_gbDevices->setTitle(i18n("Sorry. No devices found."));
         m_gbDevices->layout()->itemAt(0)->widget()->show();  // explanation
